@@ -5,19 +5,19 @@ use crate::widgets::dff::DFF;
 pub struct AutoReset {
     pub reset: Signal<Out, Reset>,
     pub clock: Signal<In, Clock>,
-    dff: DFF<Bit>,
+    dff: DFF<Bits<3>>,
 }
 
 impl Logic for AutoReset {
     #[hdl_gen]
     fn update(&mut self) {
-        self.reset.next = false.into();
-        self.dff.d.next = self.dff.q.val();
         self.dff.clock.next = self.clock.val();
         self.dff.reset.next = false.into();
-        if !self.dff.q.val() {
+        self.dff.d.next = self.dff.q.val();
+        self.reset.next = false.into();
+        if !self.dff.q.val().all() {
+            self.dff.d.next = self.dff.q.val() + 1_usize;
             self.reset.next = true.into();
-            self.dff.d.next = true;
         }
     }
 }
