@@ -40,7 +40,7 @@ pub struct I2CController {
     pub write_data_in: Signal<In, Bits<8>>,
     pub read_data_out: Signal<Out, Bits<8>>,
     pub read_valid: Signal<Out, Bit>,
-    pub reset: Signal<In, Bit>,
+    pub reset: Signal<In, Reset>,
     pub ack: Signal<Out, Bit>,
     pub nack: Signal<Out, Bit>,
     driver: I2CDriver,
@@ -84,23 +84,10 @@ impl Logic for I2CController {
     fn update(&mut self) {
         Signal::<InOut, Bit>::link(&mut self.sda, &mut self.driver.sda);
         Signal::<InOut, Bit>::link(&mut self.scl, &mut self.driver.scl);
-        self.driver.clock.next = self.clock.val();
+        clock_reset!(self, clock, reset, driver);
+        dff_setup!(self, clock, reset, counter, read_data, write_data, state, started, last_read);
         self.driver.run.next = false;
         self.driver.cmd.next = I2CDriverCmd::Noop;
-        // Clock the flops
-        self.counter.clk.next = self.clock.val();
-        self.read_data.clk.next = self.clock.val();
-        self.write_data.clk.next = self.clock.val();
-        self.state.clk.next = self.clock.val();
-        self.started.clk.next = self.clock.val();
-        self.last_read.clk.next = self.clock.val();
-        // Latch prevention
-        self.counter.d.next = self.counter.q.val();
-        self.read_data.d.next = self.read_data.q.val();
-        self.write_data.d.next = self.write_data.q.val();
-        self.state.d.next = self.state.q.val();
-        self.started.d.next = self.started.q.val();
-        self.last_read.d.next = self.last_read.q.val();
         // Default values
         self.busy.next = (self.state.q.val() != State::Idle) | self.driver.busy.val();
         self.error.next = false;
@@ -231,13 +218,9 @@ impl Logic for I2CController {
                 self.error.next = true;
             }
         }
-        if self.reset.val() {
-            self.state.d.next = State::Idle;
-        }
         if self.driver.error.val() {
             self.state.d.next = State::Error;
         }
-        self.driver.reset.next = self.reset.val();
     }
 }
 
@@ -263,6 +246,7 @@ fn test_i2c_controller_synthesizes() {
 #[derive(LogicBlock)]
 struct I2CControllerTest {
     clock: Signal<In, Clock>,
+    reset: Signal<In, Reset>,
     controller: I2CController,
     target_1: I2CTestTarget,
     target_2: I2CTestTarget,
@@ -273,9 +257,7 @@ struct I2CControllerTest {
 impl Logic for I2CControllerTest {
     #[hdl_gen]
     fn update(&mut self) {
-        self.controller.clock.next = self.clock.val();
-        self.target_1.clock.next = self.clock.val();
-        self.target_2.clock.next = self.clock.val();
+        clock_reset!(self, clock, reset, controller, target_1, target_2);
         Signal::<InOut, Bit>::join(&mut self.pullup_scl.bus, &mut self.controller.scl);
         Signal::<InOut, Bit>::join(&mut self.pullup_sda.bus, &mut self.controller.sda);
         Signal::<InOut, Bit>::join(&mut self.pullup_scl.bus, &mut self.target_1.scl);
@@ -288,7 +270,6 @@ impl Logic for I2CControllerTest {
         Signal::<InOut, Bit>::join(&mut self.controller.scl, &mut self.target_2.scl);
         self.pullup_scl.write_data.next = true;
         self.pullup_sda.write_data.next = true;
-        self.controller.reset.next = false;
     }
 }
 
@@ -300,6 +281,7 @@ impl Default for I2CControllerTest {
         };
         Self {
             clock: Default::default(),
+            reset: Default::default(),
             controller: I2CController::new(config),
             target_1: I2CTestTarget::new(0x53),
             target_2: I2CTestTarget::new(0x57),
@@ -334,6 +316,7 @@ fn test_i2c_controller_operation() {
         .collect::<Vec<_>>();
     let mut uut = I2CControllerTest::default();
     uut.clock.connect();
+    uut.reset.connect();
     uut.controller.cmd.connect();
     uut.controller.run.connect();
     uut.controller.write_data_in.connect();
@@ -356,6 +339,7 @@ fn test_i2c_controller_operation() {
     });
     sim.add_testbench(move |mut sim: Sim<I2CControllerTest>| {
         let mut x = sim.init()?;
+        reset_sim!(sim, clock, reset, x);
         // Check that a write to an invalid address is NACKed.
         i2c_begin_write!(sim, clock, x, 0x54_u32);
         sim_assert!(sim, x.controller.nack.val() & !x.controller.ack.val(), x);
@@ -386,7 +370,6 @@ fn test_i2c_controller_operation() {
         }
         sim.done(x)
     });
-    sim.run_to_file(Box::new(uut), 60_000_000_000, "i2c_controller.vcd")
+    sim.run_to_file(Box::new(uut), 80_000_000_000, "i2c_controller.vcd")
         .unwrap()
-    //    sim.run(Box::new(uut), 40_000_000_000).unwrap()
 }
