@@ -7,6 +7,7 @@ use crate::widgets::spi::master::{SPIConfig, SPIWiresSlave};
 
 #[derive(Copy, Clone, PartialEq, Debug, LogicState)]
 enum SPISlaveState {
+    Boot,
     Idle,
     Armed,
     Capture,
@@ -48,6 +49,7 @@ pub struct SPISlave<const N: usize> {
     clocks_per_baud: Constant<Bits<16>>,
     cpha: Constant<Bit>,
     cs_off: Constant<Bit>,
+    boot_delay: DFF<Bits<4>>,
 }
 
 ///
@@ -95,6 +97,7 @@ impl<const N: usize> SPISlave<N> {
             clocks_per_baud: Constant::new((2 * config.clock_speed / config.speed_hz).into()),
             cpha: Constant::new(config.cpha),
             cs_off: Constant::new(config.cs_off),
+            boot_delay: Default::default()
         }
     }
 }
@@ -114,7 +117,8 @@ impl<const N: usize> Logic for SPISlave<N> {
             pointer,
             bits_saved,
             continued_saved,
-            escape
+            escape,
+            boot_delay
         );
         clock_reset!(
             self,
@@ -149,7 +153,13 @@ impl<const N: usize> Logic for SPISlave<N> {
             .q
             .val()
             .get_bit(self.pointer.q.val().into());
+        self.boot_delay.d.next = self.boot_delay.q.val() + 1_usize;
         match self.state.q.val() {
+            SPISlaveState::Boot => {
+                if self.boot_delay.q.val() == 8_usize {
+                    self.state.d.next = SPISlaveState::Idle;
+                }
+            }
             SPISlaveState::Idle => {
                 if self.edge_detector.edge_signal.val() {
                     self.register_in.d.next = 0_u32.into();
@@ -179,7 +189,9 @@ impl<const N: usize> Logic for SPISlave<N> {
                 if self.advance_detector.edge_signal.val() {
                     self.state.d.next = SPISlaveState::Settle;
                 }
-                if self.csel_synchronizer.sig_out.val() == self.cs_off.val() {
+                // Hangup condition.  CSEL should remain low for the entire transaction.
+                if self.cpha.val() & !self.continued_saved.q.val() &
+                    (self.csel_synchronizer.sig_out.val() == self.cs_off.val()) {
                     self.state.d.next = SPISlaveState::Idle;
                 }
             }
