@@ -5,6 +5,7 @@ use rust_hdl::hls::prelude::*;
 struct RouterTest {
     router: Router<16, 8, 6>,
     clock: Signal<In, Clock>,
+    reset: Signal<In, Reset>,
 }
 
 struct DummyBridge(pub usize);
@@ -31,6 +32,7 @@ impl Default for RouterTest {
         Self {
             router,
             clock: Default::default(),
+            reset: Default::default(),
         }
     }
 }
@@ -38,6 +40,7 @@ impl Default for RouterTest {
 impl Logic for RouterTest {
     #[hdl_gen]
     fn update(&mut self) {
+        self.router.upstream.reset.next = self.reset.val();
         self.router.upstream.clock.next = self.clock.val();
     }
 }
@@ -50,11 +53,13 @@ fn make_test_router() -> RouterTest {
     uut.router.upstream.from_controller.connect();
     uut.router.upstream.strobe.connect();
     uut.router.upstream.clock.connect();
+    uut.router.upstream.reset.connect();
     for i in 0..6 {
         uut.router.nodes[i].ready.connect();
         uut.router.nodes[i].to_controller.connect();
     }
     uut.clock.connect();
+    uut.reset.connect();
     uut.router.connect_all();
     uut
 }
@@ -63,7 +68,6 @@ fn make_test_router() -> RouterTest {
 fn test_router_is_synthesizable() {
     let router = make_test_router();
     let vlog = generate_verilog(&router);
-    println!("{}", vlog);
     yosys_validate("router", &vlog).unwrap();
 }
 
@@ -74,6 +78,7 @@ fn test_router_function() {
     sim.add_clock(5, |x: &mut Box<RouterTest>| x.clock.next = !x.clock.val());
     sim.add_testbench(move |mut sim: Sim<RouterTest>| {
         let mut x = sim.init()?;
+        reset_sim!(sim, clock, reset, x);
         wait_clock_true!(sim, clock, x);
         x.router.upstream.address.next = 7_usize.into();
         x.router.upstream.address_strobe.next = true;
@@ -146,6 +151,7 @@ impl Logic for RouterTestDevice {
 fn test_device_synthesizes() {
     let mut uut = RouterTestDevice::default();
     uut.upstream.clock.connect();
+    uut.upstream.reset.connect();
     uut.upstream.from_controller.connect();
     uut.upstream.address.connect();
     uut.upstream.address_strobe.connect();
@@ -155,7 +161,6 @@ fn test_device_synthesizes() {
     }
     uut.connect_all();
     let vlog = generate_verilog(&uut);
-    println!("{}", vlog);
     yosys_validate("router_test_device", &vlog).unwrap();
 }
 
@@ -165,6 +170,7 @@ struct RouterTestSetup {
     router: Router<16, 8, 3>,
     dev_a: [RouterTestDevice; 3],
     clock: Signal<In, Clock>,
+    reset: Signal<In, Reset>,
 }
 
 impl Default for RouterTestSetup {
@@ -176,6 +182,7 @@ impl Default for RouterTestSetup {
             router: Router::new(names, [&dev_a[0], &dev_a[1], &dev_a[2]]),
             dev_a,
             clock: Default::default(),
+            reset: Default::default(),
         }
     }
 }
@@ -188,6 +195,7 @@ impl Logic for RouterTestSetup {
             SoCBusController::<16, 8>::join(&mut self.router.nodes[i], &mut self.dev_a[i].upstream);
         }
         self.upstream.clock.next = self.clock.val();
+        self.upstream.reset.next = self.reset.val();
     }
 }
 
@@ -199,6 +207,7 @@ fn make_router_test_setup() -> RouterTestSetup {
     uut.upstream.strobe.connect();
     uut.upstream.from_controller.connect();
     uut.clock.connect();
+    uut.reset.connect();
     for dev in 0..3 {
         for port in 0..5 {
             uut.dev_a[dev].mosi_ports[port].ready.connect();
@@ -212,7 +221,6 @@ fn make_router_test_setup() -> RouterTestSetup {
 fn test_router_test_setup_synthesizes() {
     let uut = make_router_test_setup();
     let vlog = generate_verilog(&uut);
-    println!("{}", vlog);
     yosys_validate("router_test_setup", &vlog).unwrap();
 }
 
@@ -229,6 +237,7 @@ fn test_router_test_setup_works() {
     ];
     sim.add_testbench(move |mut sim: Sim<RouterTestSetup>| {
         let mut x = sim.init()?;
+        reset_sim!(sim, clock, reset, x);
         wait_clock_true!(sim, clock, x);
         for address in 0_u8..15 {
             // Sweep the address space...
